(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38661,       1475]*)
(*NotebookOutlinePosition[     40562,       1534]*)
(*  CellTagsIndexPosition[     40480,       1528]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ScriptMinSize->12,
  FontSize->16],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Margins"->{1, 1},
  "Widths"->{0, 5}},
  ScriptMinSize->8,
  FontSize->11],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  StyleMenuListing->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->36,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0, 0, 0.996109],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{24, 10}, {20, 40}},
  LineSpacing->{1, 0},
  FontSize->44,
  FontColor->RGBColor[0, 0, 0.996109]],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{8, 10}, {4, 8}},
  FontSize->20,
  FontColor->RGBColor[0, 0, 0.996109]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->24,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {10, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->RGBColor[0.996109, 0, 0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{24, 10}, {15, 20}},
  LineSpacing->{1, 0},
  FontSize->36,
  FontColor->RGBColor[0.996109, 0, 0]],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{8, 10}, {4, 4}},
  FontSize->14,
  FontColor->RGBColor[0.996109, 0, 0]],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->18,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0.8, 0.300008],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{24, 10}, {10, 20}},
  LineSpacing->{1, 0},
  FontSize->24,
  FontColor->RGBColor[0, 0.8, 0.300008]],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{8, 10}, {8, 12}},
  FontSize->12,
  FontColor->RGBColor[0, 0.8, 0.300008]],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->14,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  CounterIncrements->"Section",
  CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
      "Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0, 0.500008, 0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{40, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->24,
  FontColor->RGBColor[0, 0.500008, 0]],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{18, Inherited}, {6, 12}},
  FontSize->12,
  FontColor->RGBColor[0, 0.500008, 0]],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0, 0, 0.500008],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{36, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->22,
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{16, Inherited}, {6, 12}},
  FontSize->12,
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->12,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0.500008, 0, 0.500008],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{34, 10}, {11, 26}},
  LineSpacing->{1, 0},
  FontSize->18,
  FontColor->RGBColor[0.500008, 0, 0.500008]],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{17, Inherited}, {6, 12}},
  FontSize->10,
  FontColor->RGBColor[0.500008, 0, 0.500008]],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11,
  FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section",
  TextJustification->1,
  FontFamily->"Arial"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Times"],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  TextJustification->1,
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  TextJustification->1,
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  FontFamily->"Times",
  FontSize->9],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{24, 10}, {8, 8}},
  TextJustification->1,
  LineSpacing->{1, 5},
  FontSize->12],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{8, 10}, {5, 5}},
  TextJustification->1,
  LineSpacing->{1, 2},
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontSize->7]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{72, Inherited}, {8, 10}},
  FontSize->16,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{40, 10}, {2, 3}},
  FontSize->11,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->OutputForm,
  CounterIncrements->"Output",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{72, Inherited}, {10, 8}},
  LineSpacing->{1, 0},
  FontSize->16,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{41, Inherited}, {3, 2}},
  FontSize->11,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->OutputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->GrayLevel[0],
  Background->RGBColor[1, 1, 0]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16,
  FontColor->GrayLevel[0],
  Background->RGBColor[1, 1, 0]],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontSize->11,
  FontColor->GrayLevel[0],
  Background->RGBColor[1, 1, 0]],

Cell[StyleData["Message", "Printout"],
  CellFrame->True,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.8]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->OutputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None,
  FontColor->RGBColor[1, 0, 1]],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16,
  FontColor->RGBColor[1, 0, 1]],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontSize->11,
  FontColor->RGBColor[1, 0, 1]],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  ImageMargins->{{62, Inherited}, {Inherited, 0}},
  FontSize->16],

Cell[StyleData["Graphics", "Condensed"],
  ImageSize->{175, 175},
  ImageMargins->{{38, Inherited}, {Inherited, 0}},
  FontSize->11],

Cell[StyleData["Graphics", "Printout"],
  ImageSize->{250, 250},
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->12],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->9],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Times",
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "Title"], ".", 
            CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
          FontWeight -> "Plain"]}, {None, None}},
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Center,
  FormatType->InputForm,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["NumberedEquation", "Presentation"],
  FontSize->16],

Cell[StyleData["NumberedEquation", "Condensed"],
  FontSize->11],

Cell[StyleData["NumberedEquation", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation1"],
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")  "}], FormatType -> TextForm, 
          FontWeight -> "Plain"]}, {None, None}},
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Center,
  FormatType->InputForm,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["NumberedEquation1", "Presentation"],
  FontSize->16],

Cell[StyleData["NumberedEquation1", "Condensed"],
  FontSize->11],

Cell[StyleData["NumberedEquation1", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Abbildung ", 
            CounterBox[ "Title"], ".", 
            CounterBox[ "NumberedFigure"]}]], None}},
  CounterIncrements->"NumberedFigure",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedFigure", "Presentation"],
  FontSize->16],

Cell[StyleData["NumberedFigure", "Condensed"],
  FontSize->11],

Cell[StyleData["NumberedFigure", "Printout"],
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure1"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Abbildung ", 
            CounterBox[ "NumberedFigure"]}]], None}},
  CounterIncrements->"NumberedFigure",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedFigure1", "Presentation"],
  FontSize->16],

Cell[StyleData["NumberedFigure1", "Condensed"],
  FontSize->11],

Cell[StyleData["NumberedFigure1", "Printout"],
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{44, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Tabelle ", 
            CounterBox[ "Title"], ".", 
            CounterBox[ "NumberedTable"]}]], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedTable", "Presentation"],
  FontSize->16],

Cell[StyleData["NumberedTable", "Condensed"],
  FontSize->11],

Cell[StyleData["NumberedTable", "Printout"],
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable1"],
  CellMargins->{{44, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Tabelle ", 
            CounterBox[ "NumberedTable"]}]], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedTable1", "Presentation"],
  FontSize->16],

Cell[StyleData["NumberedTable1", "Condensed"],
  FontSize->11],

Cell[StyleData["NumberedTable1", "Printout"],
  FontSize->10]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  FormatType->InputForm,
  ScriptLevel->1,
  StyleMenuListing->None,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["InlineFormula", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["InlineFormula", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{0, 0}, {6, 6}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["ChemicalFormula"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoSpacing->False,
  ScriptLevel->1,
  ScriptBaselineShifts->{0.6, Automatic},
  ZeroWidthTimes->True,
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["ChemicalFormula", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["ChemicalFormula", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["ChemicalFormula", "Printout"],
  CellMargins->{{0, 0}, {6, 6}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  ShowCellBracket->False,
  CellMargins->{{42, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  TextAlignment->Center,
  FormatType->InputForm,
  ScriptLevel->0,
  StyleMenuListing->None,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  UnderoverscriptBoxOptions->{LimitsPositioning->True},
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["DisplayFormula", "Presentation"],
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["DisplayFormula", "Condensed"],
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  ShowCellBracket->False,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["Program", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->15],

Cell[StyleData["Program", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->10.5],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{0, 0}, {6, 6}},
  FontSize->9.5]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Equation"],
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Center,
  FormatType->InputForm,
  CounterIncrements->"Equation",
  FormatTypeAutoConvert->False,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Equation", "Presentation"],
  FontSize->16],

Cell[StyleData["Equation", "Condensed"],
  FontSize->11],

Cell[StyleData["Equation", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"]],

Cell[StyleData["Hyperlink", "Condensed"]],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Presentation"]],

Cell[StyleData["MainBookLink", "Condensed"]],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Presentation"]],

Cell[StyleData["AddOnsLink", "Condensed"]],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Presentation"]],

Cell[StyleData["RefGuideLink", "Condensed"]],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Presentation"]],

Cell[StyleData["GettingStartedLink", "Condensed"]],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Presentation"]],

Cell[StyleData["OtherInformationLink", "Condensed"]],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Presentation"]],

Cell[StyleData["Placeholder", "Condensed"]],

Cell[StyleData["Placeholder", "Printout"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->Primary,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Presentation"]],

Cell[StyleData["SelectionPlaceholder", "Condensed"]],

Cell[StyleData["SelectionPlaceholder", "Printout"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontColor->GrayLevel[0]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  TextAlignment->Left,
  LineSpacing->{1.1, 0},
  StyleMenuListing->None,
  FontFamily->"Times New Roman"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{1.1, 0},
  StyleMenuListing->None,
  FontFamily->"Times New Roman"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  StyleMenuListing->None,
  FontFamily->"Times New Roman"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None,
  FontFamily->"Times"],

Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None,
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["InlineCell", "Presentation"],
  FontSize->16,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["InlineCell", "Condensed"],
  FontSize->11,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["InlineCell", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  FontFamily->"Times New Roman",
  Background->RGBColor[0, 0.8, 0.2]],

Cell[StyleData["InlineCellEditing", "Presentation"],
  FontSize->16,
  Background->RGBColor[0, 0.8, 0.2]],

Cell[StyleData["InlineCellEditing", "Condensed"],
  FontSize->11,
  Background->RGBColor[0, 0.8, 0.2]],

Cell[StyleData["InlineCellEditing", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.8]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Centered Headings", "Section",
  CellFrame->{{0, 0}, {0, 2}}],

Cell[CellGroupData[{

Cell[StyleData["CenteredTitle"],
  CellMargins->{{12, 12}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->36,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["CenteredTitle", "Presentation"],
  CellMargins->{{24, 24}, {20, 40}},
  LineSpacing->{1, 0},
  FontSize->44],

Cell[StyleData["CenteredTitle", "Condensed"],
  CellMargins->{{8, 8}, {4, 8}},
  FontSize->20],

Cell[StyleData["CenteredTitle", "Printout"],
  CellMargins->{{2, 2}, {15, 30}},
  FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CenteredSubtitle"],
  CellMargins->{{12, 12}, {10, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["CenteredSubtitle", "Presentation"],
  CellMargins->{{24, 24}, {15, 20}},
  LineSpacing->{1, 0},
  FontSize->36],

Cell[StyleData["CenteredSubtitle", "Condensed"],
  CellMargins->{{8, 8}, {4, 4}},
  FontSize->14],

Cell[StyleData["CenteredSubtitle", "Printout"],
  CellMargins->{{2, 2}, {10, 15}},
  FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CenteredSubsubtitle"],
  CellMargins->{{12, 12}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["CenteredSubsubtitle", "Presentation"],
  CellMargins->{{24, 24}, {10, 20}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["CenteredSubsubtitle", "Condensed"],
  CellMargins->{{8, 8}, {8, 12}},
  FontSize->12],

Cell[StyleData["CenteredSubsubtitle", "Printout"],
  CellMargins->{{2, 2}, {8, 10}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CenteredSection"],
  CellMargins->{{12, 12}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  TextAlignment->Center,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["CenteredSection", "Presentation"],
  CellMargins->{{24, 24}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["CenteredSection", "Condensed"],
  CellMargins->{{8, 8}, {6, 12}},
  FontSize->12],

Cell[StyleData["CenteredSection", "Printout"],
  CellMargins->{{2, 2}, {7, 22}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CenteredSubsection"],
  CellMargins->{{12, 12}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  TextAlignment->Center,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["CenteredSubsection", "Presentation"],
  CellMargins->{{24, 24}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->22],

Cell[StyleData["CenteredSubsection", "Condensed"],
  CellMargins->{{8, 8}, {6, 12}},
  FontSize->12],

Cell[StyleData["CenteredSubsection", "Printout"],
  CellMargins->{{2, 2}, {7, 22}},
  FontSize->12]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CenteredSubsubsection"],
  CellMargins->{{12, 12}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  TextAlignment->Center,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["CenteredSubsubsection", "Presentation"],
  CellMargins->{{24, 24}, {11, 26}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["CenteredSubsubsection", "Condensed"],
  CellMargins->{{8, 8}, {6, 12}},
  FontSize->10],

Cell[StyleData["CenteredSubsubsection", "Printout"],
  CellMargins->{{2, 2}, {7, 14}},
  FontSize->11]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notation Package Styles", "Section",
  GeneratedCell->True,
  CellTags->"NotationPackage"],

Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
  GeneratedCell->True,
  CellTags->"NotationPackage"],

Cell[StyleData["NotationTemplateStyle"],
  GeneratedCell->True,
  StyleMenuListing->None,
  Background->RGBColor[1, 1, 0.850004],
  CellTags->"NotationPackage"],

Cell[StyleData["NotationPatternWrapperStyle"],
  GeneratedCell->True,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.900008, 0.979995],
  CellTags->"NotationPackage"],

Cell[StyleData["NotationMadeBoxesWrapperStyle"],
  GeneratedCell->True,
  StyleMenuListing->None,
  Background->RGBColor[0.900008, 0.889998, 1],
  CellTags->"NotationPackage"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
WindowSize->{698, 451},
WindowMargins->{{Automatic, 0}, {0, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FirstPageFooter"->False,
"FacingPages"->True},
Magnification->1.5
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "NotationPackage"->{
    Cell[37803, 1444, 96, 2, 79, "Section",
      CellTags->"NotationPackage"],
    Cell[37902, 1448, 214, 5, 69, "Text",
      CellTags->"NotationPackage"],
    Cell[38119, 1455, 160, 4, 72, 40, 0, "StyleData", "NotationTemplateStyle",
     "All",
      StyleMenuListing->None,
      CellTags->"NotationPackage"],
    Cell[38282, 1461, 173, 4, 72, 46, 0, "StyleData", 
    "NotationPatternWrapperStyle", "All",
      StyleMenuListing->None,
      CellTags->"NotationPackage"],
    Cell[38458, 1467, 175, 4, 72, 48, 0, "StyleData", 
    "NotationMadeBoxesWrapperStyle", "All",
      StyleMenuListing->None,
      CellTags->"NotationPackage"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"NotationPackage", 39811, 1507}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 80, "Subtitle"],
Cell[1771, 53, 193, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 42, 0, 79, "Section"],
Cell[2034, 63, 77, 2, 48, 31, 0, "StyleData", "All", "Working"],
Cell[2114, 67, 99, 3, 55, 36, 0, "StyleData", "All", "Presentation"],
Cell[2216, 72, 158, 5, 47, 33, 0, "StyleData", "All", "Condensed"],
Cell[2377, 79, 140, 4, 45, 32, 0, "StyleData", "All", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2554, 88, 35, 0, 79, "Section"],
Cell[2592, 90, 99, 2, 46, "Text"],
Cell[2694, 94, 398, 10, 46, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Open  ]],

Cell[CellGroupData[{
Cell[3129, 109, 38, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[3192, 113, 470, 13, 163, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[3665, 128, 155, 4, 177, 40, 0, "StyleData", "Title", "Presentation"],
Cell[3823, 134, 126, 3, 65, 37, 0, "StyleData", "Title", "Condensed"],
Cell[3952, 139, 115, 3, 120, 36, 0, "StyleData", "Title", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4104, 147, 461, 13, 90, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[4568, 162, 158, 4, 125, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[4729, 168, 129, 3, 49, 40, 0, "StyleData", "Subtitle", "Condensed"],
Cell[4861, 173, 118, 3, 81, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5016, 181, 443, 12, 82, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5462, 195, 163, 4, 98, 46, 0, "StyleData", "Subsubtitle", 
"Presentation"],
Cell[5628, 201, 135, 3, 64, 43, 0, "StyleData", "Subsubtitle", "Condensed"],
Cell[5766, 206, 120, 3, 64, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5923, 214, 540, 15, 89, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
      "Subsection", 0}, {"Subsubsection", 0}}],
Cell[6466, 231, 157, 4, 117, 42, 0, "StyleData", "Section", "Presentation"],
Cell[6626, 237, 137, 3, 61, 39, 0, "StyleData", "Section", "Condensed"],
Cell[6766, 242, 116, 3, 80, 38, 0, "StyleData", "Section", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6919, 250, 479, 14, 79, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[7401, 266, 160, 4, 114, 45, 0, "StyleData", "Subsection", 
"Presentation"],
Cell[7564, 272, 140, 3, 61, 42, 0, "StyleData", "Subsection", "Condensed"],
Cell[7707, 277, 118, 3, 77, 41, 0, "StyleData", "Subsection", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7862, 285, 446, 13, 73, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[8311, 300, 170, 4, 99, 48, 0, "StyleData", "Subsubsection", 
"Presentation"],
Cell[8484, 306, 150, 3, 57, 45, 0, "StyleData", "Subsubsection", "Condensed"],

Cell[8637, 311, 121, 3, 63, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8807, 320, 86, 2, 77, "Section"],

Cell[CellGroupData[{
Cell[8918, 326, 157, 5, 55, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[9078, 333, 139, 4, 71, 39, 0, "StyleData", "Text", "Presentation"],
Cell[9220, 339, 133, 4, 50, 36, 0, "StyleData", "Text", "Condensed"],
Cell[9356, 345, 108, 3, 48, 35, 0, "StyleData", "Text", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9501, 353, 182, 6, 47, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[9686, 361, 142, 4, 58, 44, 0, "StyleData", "SmallText", "Presentation"],
Cell[9831, 367, 137, 4, 44, 41, 0, "StyleData", "SmallText", "Condensed"],
Cell[9971, 373, 112, 3, 42, 40, 0, "StyleData", "SmallText", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10132, 382, 42, 0, 77, "Section"],
Cell[10177, 384, 246, 4, 96, "Text"],

Cell[CellGroupData[{
Cell[10448, 392, 499, 15, 52, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[10950, 409, 131, 3, 68, 40, 0, "StyleData", "Input", "Presentation"],
Cell[11084, 414, 120, 3, 39, 37, 0, "StyleData", "Input", "Condensed"],
Cell[11207, 419, 113, 3, 45, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11357, 427, 487, 14, 52, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[11847, 443, 155, 4, 68, 41, 0, "StyleData", "Output", "Presentation"],
Cell[12005, 449, 128, 3, 39, 38, 0, "StyleData", "Output", "Condensed"],
Cell[12136, 454, 114, 3, 45, 37, 0, "StyleData", "Output", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12287, 462, 530, 15, 70, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[12820, 479, 199, 5, 77, 42, 0, "StyleData", "Message", "Presentation"],
Cell[13022, 486, 173, 4, 68, 39, 0, "StyleData", "Message", "Condensed"],
Cell[13198, 492, 188, 5, 66, 38, 0, "StyleData", "Message", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13423, 502, 531, 15, 46, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[13957, 519, 169, 4, 53, 40, 0, "StyleData", "Print", "Presentation"],
Cell[14129, 525, 143, 3, 44, 37, 0, "StyleData", "Print", "Condensed"],
Cell[14275, 530, 137, 3, 42, 36, 0, "StyleData", "Print", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14449, 538, 439, 12, 46, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[14891, 552, 110, 2, 53, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[15004, 556, 132, 3, 44, 40, 0, "StyleData", "Graphics", "Condensed"],
Cell[15139, 561, 131, 3, 42, 39, 0, "StyleData", "Graphics", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15307, 569, 126, 4, 41, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[15436, 575, 60, 1, 44, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[15499, 578, 56, 1, 41, 41, 0, "StyleData", "CellLabel", "Condensed"],
Cell[15558, 581, 105, 3, 40, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15712, 590, 49, 0, 77, "Section"],
Cell[15764, 592, 225, 4, 96, "Text"],

Cell[CellGroupData[{
Cell[16014, 600, 521, 12, 46, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[16538, 614, 67, 1, 53, 51, 0, "StyleData", "NumberedEquation", 
"Presentation"],
Cell[16608, 617, 64, 1, 44, 48, 0, "StyleData", "NumberedEquation", 
"Condensed"],
Cell[16675, 620, 90, 2, 42, 47, 0, "StyleData", "NumberedEquation", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16802, 627, 427, 10, 46, 36, 0, "StyleData", "NumberedEquation1", "All",
  CounterIncrements->"NumberedEquation"],
Cell[17232, 639, 68, 1, 53, 52, 0, "StyleData", "NumberedEquation1", 
"Presentation"],
Cell[17303, 642, 65, 1, 44, 49, 0, "StyleData", "NumberedEquation1", 
"Condensed"],
Cell[17371, 645, 91, 2, 42, 48, 0, "StyleData", "NumberedEquation1", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17499, 652, 384, 8, 76, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[17886, 662, 65, 1, 90, 49, 0, "StyleData", "NumberedFigure", 
"Presentation"],
Cell[17954, 665, 62, 1, 72, 46, 0, "StyleData", "NumberedFigure", 
"Condensed"],
Cell[18019, 668, 61, 1, 68, 45, 0, "StyleData", "NumberedFigure", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18117, 674, 345, 7, 76, 34, 0, "StyleData", "NumberedFigure1", "All",
  CounterIncrements->"NumberedFigure"],
Cell[18465, 683, 66, 1, 90, 50, 0, "StyleData", "NumberedFigure1", 
"Presentation"],
Cell[18534, 686, 63, 1, 72, 47, 0, "StyleData", "NumberedFigure1", 
"Condensed"],
Cell[18600, 689, 62, 1, 68, 46, 0, "StyleData", "NumberedFigure1", "Printout"]

}, Open  ]],

Cell[CellGroupData[{
Cell[18699, 695, 354, 8, 76, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[19056, 705, 64, 1, 90, 48, 0, "StyleData", "NumberedTable", 
"Presentation"],
Cell[19123, 708, 61, 1, 72, 45, 0, "StyleData", "NumberedTable", "Condensed"],

Cell[19187, 711, 60, 1, 68, 44, 0, "StyleData", "NumberedTable", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19284, 717, 315, 7, 76, 33, 0, "StyleData", "NumberedTable1", "All",
  CounterIncrements->"NumberedTable"],
Cell[19602, 726, 65, 1, 90, 49, 0, "StyleData", "NumberedTable1", 
"Presentation"],
Cell[19670, 729, 62, 1, 72, 46, 0, "StyleData", "NumberedTable1", 
"Condensed"],
Cell[19735, 732, 61, 1, 68, 45, 0, "StyleData", "NumberedTable1", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19845, 739, 43, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[19913, 743, 293, 9, 46, 32, 0, "StyleData", "InlineFormula", "All",
  StyleMenuListing->None],
Cell[20209, 754, 124, 3, 71, 48, 0, "StyleData", "InlineFormula", 
"Presentation"],
Cell[20336, 759, 118, 3, 50, 45, 0, "StyleData", "InlineFormula", 
"Condensed"],
Cell[20457, 764, 120, 3, 48, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20614, 772, 278, 8, 46, 34, 0, "StyleData", "ChemicalFormula", "All"],
Cell[20895, 782, 110, 2, 64, 50, 0, "StyleData", "ChemicalFormula", 
"Presentation"],
Cell[21008, 786, 104, 2, 52, 47, 0, "StyleData", "ChemicalFormula", 
"Condensed"],
Cell[21115, 790, 79, 1, 52, 46, 0, "StyleData", "ChemicalFormula", "Printout"]

}, Open  ]],

Cell[CellGroupData[{
Cell[21231, 796, 399, 11, 46, 33, 0, "StyleData", "DisplayFormula", "All",
  StyleMenuListing->None],
Cell[21633, 809, 88, 2, 53, 49, 0, "StyleData", "DisplayFormula", 
"Presentation"],
Cell[21724, 813, 85, 2, 44, 46, 0, "StyleData", "DisplayFormula", 
"Condensed"],
Cell[21812, 817, 88, 2, 42, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21937, 824, 170, 5, 44, 26, 0, "StyleData", "Program", "All",
  StyleMenuListing->None],
Cell[22110, 831, 118, 3, 67, 42, 0, "StyleData", "Program", "Presentation"],
Cell[22231, 836, 114, 3, 49, 39, 0, "StyleData", "Program", "Condensed"],
Cell[22348, 841, 88, 2, 47, 38, 0, "StyleData", "Program", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22473, 848, 220, 6, 46, 27, 0, "StyleData", "Equation", "All",
  CounterIncrements->"Equation"],
Cell[22696, 856, 59, 1, 53, 43, 0, "StyleData", "Equation", "Presentation"],
Cell[22758, 859, 56, 1, 44, 40, 0, "StyleData", "Equation", "Condensed"],
Cell[22817, 862, 82, 2, 42, 39, 0, "StyleData", "Equation", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22948, 870, 49, 0, 77, "Section"],
Cell[23000, 872, 150, 5, 37, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[23153, 879, 149, 5, 35, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[23305, 886, 176, 6, 37, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Open  ]],

Cell[CellGroupData[{
Cell[23518, 897, 33, 0, 77, "Section"],
Cell[23554, 899, 121, 3, 71, "Text"],
Cell[23678, 904, 226, 5, 46, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23907, 911, 295, 7, 46, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24205, 920, 400, 9, 46, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24608, 931, 387, 9, 46, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24998, 942, 401, 9, 46, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[25436, 956, 35, 0, 77, "Section"],
Cell[25474, 958, 184, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[25683, 966, 302, 8, 46, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[25988, 976, 44, 0, 46, 44, 0, "StyleData", "Hyperlink", "Presentation"],
Cell[26035, 978, 41, 0, 46, 41, 0, "StyleData", "Hyperlink", "Condensed"],
Cell[26079, 980, 107, 2, 46, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Open  ]],
Cell[26201, 985, 104, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[26330, 992, 339, 9, 46, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[26672, 1003, 47, 0, 46, 47, 0, "StyleData", "MainBookLink", 
"Presentation"],
Cell[26722, 1005, 44, 0, 46, 44, 0, "StyleData", "MainBookLink", "Condensed"],

Cell[26769, 1007, 110, 2, 46, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26916, 1014, 358, 10, 46, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27277, 1026, 45, 0, 46, 45, 0, "StyleData", "AddOnsLink", 
"Presentation"],
Cell[27325, 1028, 42, 0, 46, 42, 0, "StyleData", "AddOnsLink", "Condensed"],
Cell[27370, 1030, 107, 2, 46, 40, 0, "StyleData", "AddOnLink", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27514, 1037, 368, 10, 44, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27885, 1049, 47, 0, 44, 47, 0, "StyleData", "RefGuideLink", 
"Presentation"],
Cell[27935, 1051, 44, 0, 44, 44, 0, "StyleData", "RefGuideLink", "Condensed"],

Cell[27982, 1053, 110, 2, 44, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28129, 1060, 374, 10, 46, 37, 0, "StyleData", "GettingStartedLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28506, 1072, 53, 0, 46, 53, 0, "StyleData", "GettingStartedLink", 
"Presentation"],
Cell[28562, 1074, 50, 0, 46, 50, 0, "StyleData", "GettingStartedLink", 
"Condensed"],
Cell[28615, 1076, 116, 2, 46, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28768, 1083, 378, 10, 46, 39, 0, "StyleData", "OtherInformationLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29149, 1095, 55, 0, 46, 55, 0, "StyleData", "OtherInformationLink", 
"Presentation"],
Cell[29207, 1097, 52, 0, 46, 52, 0, "StyleData", "OtherInformationLink", 
"Condensed"],
Cell[29262, 1099, 118, 2, 46, 51, 0, "StyleData", "OtherInformationLink", 
"Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29429, 1107, 37, 0, 77, "Section"],
Cell[29469, 1109, 115, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[29609, 1116, 145, 5, 46, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[29757, 1123, 46, 0, 46, 46, 0, "StyleData", "Placeholder", 
"Presentation"],
Cell[29806, 1125, 43, 0, 46, 43, 0, "StyleData", "Placeholder", "Condensed"],
Cell[29852, 1127, 42, 0, 46, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29931, 1132, 182, 6, 46, 39, 0, "StyleData", "SelectionPlaceholder", 
"All",
  StyleMenuListing->None],
Cell[30116, 1140, 55, 0, 46, 55, 0, "StyleData", "SelectionPlaceholder", 
"Presentation"],
Cell[30174, 1142, 52, 0, 46, 52, 0, "StyleData", "SelectionPlaceholder", 
"Condensed"],
Cell[30229, 1144, 51, 0, 46, 51, 0, "StyleData", "SelectionPlaceholder", 
"Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30329, 1150, 36, 0, 77, "Section"],
Cell[30368, 1152, 258, 5, 96, "Text"],
Cell[30629, 1159, 274, 8, 44, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[30906, 1169, 162, 5, 46, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[31071, 1176, 159, 5, 46, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[31233, 1183, 145, 4, 46, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[31381, 1189, 202, 6, 46, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[31586, 1197, 115, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[31726, 1204, 183, 6, 46, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[31912, 1212, 93, 2, 53, 45, 0, "StyleData", "InlineCell", 
"Presentation"],
Cell[32008, 1216, 90, 2, 44, 42, 0, "StyleData", "InlineCell", "Condensed"],
Cell[32101, 1220, 84, 2, 42, 41, 0, "StyleData", "InlineCell", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32222, 1227, 132, 3, 70, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None],
Cell[32357, 1232, 105, 2, 77, 52, 0, "StyleData", "InlineCellEditing", 
"Presentation"],
Cell[32465, 1236, 102, 2, 68, 49, 0, "StyleData", "InlineCellEditing", 
"Condensed"],
Cell[32570, 1240, 94, 2, 66, 48, 0, "StyleData", "InlineCellEditing", 
"Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32713, 1248, 78, 1, 92, "Section"],

Cell[CellGroupData[{
Cell[32816, 1253, 484, 14, 163, 32, 0, "StyleData", "CenteredTitle", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[33303, 1269, 124, 3, 177, 48, 0, "StyleData", "CenteredTitle", 
"Presentation"],
Cell[33430, 1274, 94, 2, 65, 45, 0, "StyleData", "CenteredTitle", 
"Condensed"],
Cell[33527, 1278, 95, 2, 120, 44, 0, "StyleData", "CenteredTitle", "Printout"]

}, Open  ]],

Cell[CellGroupData[{
Cell[33659, 1285, 475, 14, 72, 35, 0, "StyleData", "CenteredSubtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[34137, 1301, 127, 3, 125, 51, 0, "StyleData", "CenteredSubtitle", 
"Presentation"],
Cell[34267, 1306, 97, 2, 49, 48, 0, "StyleData", "CenteredSubtitle", 
"Condensed"],
Cell[34367, 1310, 98, 2, 81, 47, 0, "StyleData", "CenteredSubtitle", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34502, 1317, 455, 13, 56, 38, 0, "StyleData", "CenteredSubsubtitle", 
"All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[34960, 1332, 130, 3, 89, 54, 0, "StyleData", "CenteredSubsubtitle", 
"Presentation"],
Cell[35093, 1337, 101, 2, 59, 51, 0, "StyleData", "CenteredSubsubtitle", 
"Condensed"],
Cell[35197, 1341, 100, 2, 59, 50, 0, "StyleData", "CenteredSubsubtitle", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35334, 1348, 467, 14, 57, 34, 0, "StyleData", "CenteredSection", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[35804, 1364, 126, 3, 105, 50, 0, "StyleData", "CenteredSection", 
"Presentation"],
Cell[35933, 1369, 97, 2, 56, 47, 0, "StyleData", "CenteredSection", 
"Condensed"],
Cell[36033, 1373, 96, 2, 73, 46, 0, "StyleData", "CenteredSection", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36166, 1380, 454, 14, 53, 37, 0, "StyleData", "CenteredSubsection", 
"All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[36623, 1396, 129, 3, 114, 53, 0, "StyleData", "CenteredSubsection", 
"Presentation"],
Cell[36755, 1401, 100, 2, 61, 50, 0, "StyleData", "CenteredSubsection", 
"Condensed"],
Cell[36858, 1405, 99, 2, 77, 49, 0, "StyleData", "CenteredSubsection", 
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36994, 1412, 414, 13, 73, 40, 0, "StyleData", "CenteredSubsubsection", 
"All",
  CounterIncrements->"Subsubsection"],
Cell[37411, 1427, 132, 3, 102, 56, 0, "StyleData", "CenteredSubsubsection", 
"Presentation"],
Cell[37546, 1432, 103, 2, 60, 53, 0, "StyleData", "CenteredSubsubsection", 
"Condensed"],
Cell[37652, 1436, 102, 2, 66, 52, 0, "StyleData", "CenteredSubsubsection", 
"Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37803, 1444, 96, 2, 79, "Section",
  CellTags->"NotationPackage"],
Cell[37902, 1448, 214, 5, 69, "Text",
  CellTags->"NotationPackage"],
Cell[38119, 1455, 160, 4, 72, 40, 0, "StyleData", "NotationTemplateStyle", 
"All",
  StyleMenuListing->None,
  CellTags->"NotationPackage"],
Cell[38282, 1461, 173, 4, 72, 46, 0, "StyleData", 
"NotationPatternWrapperStyle", "All",
  StyleMenuListing->None,
  CellTags->"NotationPackage"],
Cell[38458, 1467, 175, 4, 72, 48, 0, "StyleData", 
"NotationMadeBoxesWrapperStyle", "All",
  StyleMenuListing->None,
  CellTags->"NotationPackage"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

